param($installPath, $toolsPath, $package, $project)

if($project.Object.SupportsPackageDependencyResolution)
{
	if($project.Object.SupportsPackageDependencyResolution())
	{
		# Do not install analyzers via install.ps1, instead let the project system handle it.
		return
	}
}

$analyzersPaths = Join-Path (Join-Path (Split-Path -Path $toolsPath -Parent) "analyzers") * -Resolve

foreach($analyzersPath in $analyzersPaths)
{
	if (Test-Path $analyzersPath)
	{
		# Install the language agnostic analyzers.
		foreach ($analyzerFilePath in Get-ChildItem -Path "$analyzersPath\*.dll" -Exclude *.resources.dll)
		{
			if($project.Object.AnalyzerReferences)
			{
				$project.Object.AnalyzerReferences.Add($analyzerFilePath.FullName)
			}
		}
	}
}

# $project.Type gives the language name like (C# or VB.NET)
$languageFolder = ""
if($project.Type -eq "C#")
{
	$languageFolder = "cs"
}
if($project.Type -eq "VB.NET")
{
	$languageFolder = "vb"
}
if($languageFolder -eq "")
{
	return
}

foreach($analyzersPath in $analyzersPaths)
{
	# Install language specific analyzers.
	$languageAnalyzersPath = join-path $analyzersPath $languageFolder
	if (Test-Path $languageAnalyzersPath)
	{
		foreach ($analyzerFilePath in Get-ChildItem -Path "$languageAnalyzersPath\*.dll" -Exclude *.resources.dll)
		{
			if($project.Object.AnalyzerReferences)
			{
				$project.Object.AnalyzerReferences.Add($analyzerFilePath.FullName)
			}
		}
	}
}

# SIG # Begin signature block
# MIIqUgYJKoZIhvcNAQcCoIIqQzCCKj8CAQExDzANBglghkgBZQMEAgEFADB5Bgor
# BgEEAYI3AgEEoGswaTA0BgorBgEEAYI3AgEeMCYCAwEAAAQQH8w7YFlLCE63JNLG
# KX7zUQIBAAIBAAIBAAIBAAIBADAxMA0GCWCGSAFlAwQCAQUABCCUan8mf4waWMwA
# TH73bpoSYEQbEfLSaT+RMkxvRyNnPqCCDvQwggPFMIICraADAgECAhACrFwmagtA
# m48LefKuRiV3MA0GCSqGSIb3DQEBBQUAMGwxCzAJBgNVBAYTAlVTMRUwEwYDVQQK
# EwxEaWdpQ2VydCBJbmMxGTAXBgNVBAsTEHd3dy5kaWdpY2VydC5jb20xKzApBgNV
# BAMTIkRpZ2lDZXJ0IEhpZ2ggQXNzdXJhbmNlIEVWIFJvb3QgQ0EwHhcNMDYxMTEw
# MDAwMDAwWhcNMzExMTEwMDAwMDAwWjBsMQswCQYDVQQGEwJVUzEVMBMGA1UEChMM
# RGlnaUNlcnQgSW5jMRkwFwYDVQQLExB3d3cuZGlnaWNlcnQuY29tMSswKQYDVQQD
# EyJEaWdpQ2VydCBIaWdoIEFzc3VyYW5jZSBFViBSb290IENBMIIBIjANBgkqhkiG
# 9w0BAQEFAAOCAQ8AMIIBCgKCAQEAxszlc+b71LvlLS0ypt/lgT/JzSVJtnEqw9WU
# NGeiChywX2mmQLHEt7KP0JikqUFZOtPclNY823Q4pErMTSWC90qlUxI47vNJbXGR
# fmO2q6Zfw6SE+E9iUb74xezbOJLjBuUIkQzEKEFV+8taiRV+ceg1v01yCT2+OjhQ
# W3cxG42zxyRFmqesbQAUWgS3uhPrUQqYQUEiTmVhh4FBUKZ5XIneGUpX1S7mXRxT
# LH6YzRoGFqRoc9A0BBNcoXHTWnxV215k4TeHMFYE5RG0KYAS8Xk5iKICEXwnZreI
# t3jyygqoOKsKZMK/Zl2VhMGhJR6HXRpQCyASzEG7bgtROLhLywIDAQABo2MwYTAO
# BgNVHQ8BAf8EBAMCAYYwDwYDVR0TAQH/BAUwAwEB/zAdBgNVHQ4EFgQUsT7DaQP4
# v0cB1JgmGggC72NkK8MwHwYDVR0jBBgwFoAUsT7DaQP4v0cB1JgmGggC72NkK8Mw
# DQYJKoZIhvcNAQEFBQADggEBABwaBpfc15yfPIhmBghXIdshR/gqZ6q/GDJ2QBBX
# wYrzetkRZY41+p78RbWe2UwxS7iR6EMsjrN4ztvjU3lx1uUhlAHaVYeaJGT2imbM
# 3pw3zag0sWmbI8ieeCIrcEPjVUcxYRnvWMWFL04w9qAxFiPI5+JlFjPLvxoboD34
# yl6LMYtgCIktDAZcUrfE+QqY0RVfnxK+fDZjOL1EpH/kJisKxJdpDemM4sAQV7jI
# dhKRVfJIadi8KgJbD0TUIDHb9LpwJl2QYJ68SxcJL7TLHkNoyQcnwdJc9+ohuWgS
# nDycv578gFybY83sR6olJ2egN/MAgn1U16n46S4To3foH0owggSRMIIDeaADAgEC
# AhAHsEGNpR4UjDMbvN63E4MjMA0GCSqGSIb3DQEBCwUAMGwxCzAJBgNVBAYTAlVT
# MRUwEwYDVQQKEwxEaWdpQ2VydCBJbmMxGTAXBgNVBAsTEHd3dy5kaWdpY2VydC5j
# b20xKzApBgNVBAMTIkRpZ2lDZXJ0IEhpZ2ggQXNzdXJhbmNlIEVWIFJvb3QgQ0Ew
# HhcNMTgwNDI3MTI0MTU5WhcNMjgwNDI3MTI0MTU5WjBaMQswCQYDVQQGEwJVUzEY
# MBYGA1UEChMPLk5FVCBGb3VuZGF0aW9uMTEwLwYDVQQDEyguTkVUIEZvdW5kYXRp
# b24gUHJvamVjdHMgQ29kZSBTaWduaW5nIENBMIIBIjANBgkqhkiG9w0BAQEFAAOC
# AQ8AMIIBCgKCAQEAwQqv4aI0CI20XeYqTTZmyoxsSQgcCBGQnXnufbuDLhAB6GoT
# NB7HuEhNSS8ftV+6yq8GztBzYAJ0lALdBjWypMfL451/84AO5ZiZB3V7MB2uxgWo
# cV1ekDduU9bm1Q48jmR4SVkLItC+oQO/FIA2SBudVZUvYKeCJS5Ri9ibV7La4oo7
# BJChFiP8uR+v3OU33dgm5BBhWmth4oTyq22zCfP3NO6gBWEIPFR5S+KcefUTYmn2
# o7IvhvxzJsMCrNH1bxhwOyMl+DQcdWiVPuJBKDOO/hAKIxBG4i6ryQYBaKdhDgaA
# NSCik0UgZasz8Qgl8n0A73+dISPumD8L/4mdywIDAQABo4IBPzCCATswHQYDVR0O
# BBYEFMtck66Im/5Db1ZQUgJtePys4bFaMB8GA1UdIwQYMBaAFLE+w2kD+L9HAdSY
# JhoIAu9jZCvDMA4GA1UdDwEB/wQEAwIBhjATBgNVHSUEDDAKBggrBgEFBQcDAzAS
# BgNVHRMBAf8ECDAGAQH/AgEAMDQGCCsGAQUFBwEBBCgwJjAkBggrBgEFBQcwAYYY
# aHR0cDovL29jc3AuZGlnaWNlcnQuY29tMEsGA1UdHwREMEIwQKA+oDyGOmh0dHA6
# Ly9jcmwzLmRpZ2ljZXJ0LmNvbS9EaWdpQ2VydEhpZ2hBc3N1cmFuY2VFVlJvb3RD
# QS5jcmwwPQYDVR0gBDYwNDAyBgRVHSAAMCowKAYIKwYBBQUHAgEWHGh0dHBzOi8v
# d3d3LmRpZ2ljZXJ0LmNvbS9DUFMwDQYJKoZIhvcNAQELBQADggEBALNGxKTz6gq6
# clMF01GjC3RmJ/ZAoK1V7rwkqOkY3JDl++v1F4KrFWEzS8MbZsI/p4W31Eketazo
# Nxy23RT0zDsvJrwEC3R+/MRdkB7aTecsYmMeMHgtUrl3xEO3FubnQ0kKEU/HBCTd
# hR14GsQEccQQE6grFVlglrew+FzehWUu3SUQEp9t+iWpX/KfviDWx0H1azilMX15
# lzJUxK7kCzmflrk5jCOCjKqhOdGJoQqstmwP+07qXO18bcCzEC908P+TYkh0z9gV
# rlj7tyW9K9zPVPJZsLRaBp/QjMcH65o9Y1hD1uWtFQYmbEYkT1K9tuXHtQYx1Rpf
# /dC8Nbl4iukwggaSMIIFeqADAgECAhALZYHUD3H36++YNL7DL2PeMA0GCSqGSIb3
# DQEBCwUAMFoxCzAJBgNVBAYTAlVTMRgwFgYDVQQKEw8uTkVUIEZvdW5kYXRpb24x
# MTAvBgNVBAMTKC5ORVQgRm91bmRhdGlvbiBQcm9qZWN0cyBDb2RlIFNpZ25pbmcg
# Q0EwHhcNMjEwMzA1MDAwMDAwWhcNMjQwNjAxMjM1OTU5WjCBjjEUMBIGA1UEBRML
# NjAzIDM4OSAwNjgxCzAJBgNVBAYTAlVTMQswCQYDVQQIEwJXQTEQMA4GA1UEBxMH
# UmVkbW9uZDEkMCIGA1UEChMbeFVuaXQubmV0ICguTkVUIEZvdW5kYXRpb24pMSQw
# IgYDVQQDExt4VW5pdC5uZXQgKC5ORVQgRm91bmRhdGlvbikwggIiMA0GCSqGSIb3
# DQEBAQUAA4ICDwAwggIKAoICAQC7Zs6Ng5KXq1e1R/ZpLG5l1xt6sUmY4GqfL7nB
# gQBpHpe6p7om04J6z5FaBLQRscDOo90StsUtolHAVuIhPBxxbBusJRiB6hHtHyaS
# e5rRsoKVzTQqDOxzrw5HIiq1/SFqJfT5vKTmfNDsFBVNfTbeNF8W0CScuG07rQeu
# gEc3vmmKQjBXl8RwuIlQUkhgmkh5g1A71ipibSvb5XsiZY+nz3lksL/69meWjvOI
# LZbD4TcI1MlAZbZliNfrGJpRAJk2KHN+E5+Lz8rsZMnOvl14TeiWh7tX5CUHB17A
# WWZMoRCGuSpvZ0nwELjYRO+huZTRrTGM/1iTK/xJ08TIK0ouuyihHTOMuzuprpXu
# JEKJapgQ0oAIDM5wGuxJIgcrlgLdjeg9qR7Qgpk80OFDFCt22fMxPKWYUrvaN9CP
# 1qUvzU0csEaMGbqaXvDxW4Jh5qMq6stiD9u1ZlbQXLd7cGgdLFZkG2SHYGRlsLSJ
# CCiA+xhFpyq6paLwByVyiRomN2RoKziR2yIFy04hHt1dxdCxstLU7IYepMPD2hq8
# LrQsJKtLs3oukf9hGm9mg/Ob6hfjYKO9WeFBoArZJJsAy+3yhOOvXakAeZyAaZKL
# 2W+ytTIBkEwOvpVxZoV1M0acQ1B9NlaVO29RJ6EQlWdcsN9+HA2tcJ3fSGAai+bf
# I4TJiQIDAQABo4ICHTCCAhkwHwYDVR0jBBgwFoAUy1yTroib/kNvVlBSAm14/Kzh
# sVowHQYDVR0OBBYEFE1FuBWTKAW2LOHLbCt+NrwdAW09MDQGA1UdEQQtMCugKQYI
# KwYBBQUHCAOgHTAbDBlVUy1XQVNISU5HVE9OLTYwMyAzODkgMDY4MA4GA1UdDwEB
# /wQEAwIHgDATBgNVHSUEDDAKBggrBgEFBQcDAzCBmQYDVR0fBIGRMIGOMEWgQ6BB
# hj9odHRwOi8vY3JsMy5kaWdpY2VydC5jb20vTkVURm91bmRhdGlvblByb2plY3Rz
# Q29kZVNpZ25pbmdDQS5jcmwwRaBDoEGGP2h0dHA6Ly9jcmw0LmRpZ2ljZXJ0LmNv
# bS9ORVRGb3VuZGF0aW9uUHJvamVjdHNDb2RlU2lnbmluZ0NBLmNybDBLBgNVHSAE
# RDBCMDYGCWCGSAGG/WwDATApMCcGCCsGAQUFBwIBFhtodHRwOi8vd3d3LmRpZ2lj
# ZXJ0LmNvbS9DUFMwCAYGZ4EMAQQBMIGEBggrBgEFBQcBAQR4MHYwJAYIKwYBBQUH
# MAGGGGh0dHA6Ly9vY3NwLmRpZ2ljZXJ0LmNvbTBOBggrBgEFBQcwAoZCaHR0cDov
# L2NhY2VydHMuZGlnaWNlcnQuY29tL05FVEZvdW5kYXRpb25Qcm9qZWN0c0NvZGVT
# aWduaW5nQ0EuY3J0MAwGA1UdEwEB/wQCMAAwDQYJKoZIhvcNAQELBQADggEBAI1A
# ruHc8L6TuwQC561WdwZ67LcwTmL26+W6d4m8WEXmM1RCms1Ipi0XuGL4ts9+dQbO
# yM+zB+OcTEuZpD4XuAkvthV1A5GpUJZa2hnbMgf7FeknluJF4KOpGT9ABn10tAUP
# LYEqGZONKZnJB5yjVXEIbfNrOp6WRJCQOvZSKE2Oj9CfJ6KZmaJd/gXfQzPR6oPT
# +qL/vxPvl+iyM7Cnj8e7v4GeYhKvlbnA2q5/FiBKLCNMq2B7VqNDr69wCfYgV0gi
# A19U/37d88Sz8dfJwXpAiNzrYfgrdBWlZpq8PHkKjqlCRxOr71ESnWUv7Q6Qneae
# BznvWh02DlXUPGIWMCQxghq0MIIasAIBATBuMFoxCzAJBgNVBAYTAlVTMRgwFgYD
# VQQKEw8uTkVUIEZvdW5kYXRpb24xMTAvBgNVBAMTKC5ORVQgRm91bmRhdGlvbiBQ
# cm9qZWN0cyBDb2RlIFNpZ25pbmcgQ0ECEAtlgdQPcffr75g0vsMvY94wDQYJYIZI
# AWUDBAIBBQCgga4wGQYJKoZIhvcNAQkDMQwGCisGAQQBgjcCAQQwHAYKKwYBBAGC
# NwIBCzEOMAwGCisGAQQBgjcCARUwLwYJKoZIhvcNAQkEMSIEIAQ4DsysYSOgMRyM
# 7y6DDAc4qaI8ql+XwW5108bCafx+MEIGCisGAQQBgjcCAQwxNDAyoBSAEgB4AFUA
# bgBpAHQALgBuAGUAdKEagBhodHRwczovL2dpdGh1Yi5jb20veHVuaXQwDQYJKoZI
# hvcNAQEBBQAEggIAQuDwzEw7HBxkGNasr59o+3mQ/TmxKvHLlaslRpcG5zLrIztQ
# eKoZJAiw4zg7Bh3zLaIR3LYyITY2WoeUOkdy1RPwnFFbSxUU4aNSLkH6tJ/mYPHD
# par/NCFtICmNbnpBYJDgR82tq1lX9MMTWFUd9hyM29CtXcfJ8HCdmKqoWi1uul6d
# jmeDDxzpRUdcrv1YSxQnBTFaGFGNZbL47nw1C5SO/b2WY08S5+rZ1pJQIWcYIvMe
# Lt0EZc1XJfDo0cUpgw7pqU60CVN8o9fCbddOJtWzeqjUAKF51TjvSHRXB1toVRfq
# PLmDAvHJw+YGYx/Irtq5QdzU2qQehkGDP9Pav8x8peCgcf6wlq/uvotkARoCAuPO
# OtBrMp+w20hbUBPJCu8AvGqY73PWxG28Vm3qPbNTQQ0jk5ejEcLQlWxKykWjQ53S
# pESvMGe+7bcQ1/0mUeMasCKwk3VjuKFB/imrSEbVzOUeTmUgX1XLZGdhhLyDyaxo
# rQ1ICj9M8m73CdfE4sPS7ypRhvdzLeGSxn/0D/mAt0FBOXM3K3kPtvT52EJ9rnRw
# Qc5eECiSSNvblXWMi494g4YWSWORzsKUd1QthaNOtsa+FRFOGl159VRREjiWu7Sg
# MzuFN7sq2WMlt3MmMDmh8HH2u3/72tVyL8iNCCjAxk4Jo/UHQk9RBcpF6g2hghdm
# MIIXYgYKKwYBBAGCNwMDATGCF1IwghdOBgkqhkiG9w0BBwKgghc/MIIXOwIBAzEP
# MA0GCWCGSAFlAwQCAQUAMIIBYQYLKoZIhvcNAQkQAQSgggFQBIIBTDCCAUgCAQEG
# CisGAQQBhFkKAwEwMTANBglghkgBZQMEAgEFAAQgRozWIoZCyGHBxTpFApFH0Z7l
# rs8eTH6L4BcVZhusfAkCBmRr7icoqxgTMjAyMzA1MjYwMjA1NDAuMjM0WjAEgAIB
# 9KCB4KSB3TCB2jELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAO
# BgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEl
# MCMGA1UECxMcTWljcm9zb2Z0IEFtZXJpY2EgT3BlcmF0aW9uczEmMCQGA1UECxMd
# VGhhbGVzIFRTUyBFU046M0RBNS05NjNCLUUxRjQxNTAzBgNVBAMTLE1pY3Jvc29m
# dCBQdWJsaWMgUlNBIFRpbWUgU3RhbXBpbmcgQXV0aG9yaXR5oIIR5jCCB4IwggVq
# oAMCAQICEzMAAAAF5c8P/2YuyYcAAAAAAAUwDQYJKoZIhvcNAQEMBQAwdzELMAkG
# A1UEBhMCVVMxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjFIMEYGA1UE
# AxM/TWljcm9zb2Z0IElkZW50aXR5IFZlcmlmaWNhdGlvbiBSb290IENlcnRpZmlj
# YXRlIEF1dGhvcml0eSAyMDIwMB4XDTIwMTExOTIwMzIzMVoXDTM1MTExOTIwNDIz
# MVowYTELMAkGA1UEBhMCVVMxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlv
# bjEyMDAGA1UEAxMpTWljcm9zb2Z0IFB1YmxpYyBSU0EgVGltZXN0YW1waW5nIENB
# IDIwMjAwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQCefOdSY/3gxZ8F
# fWO1BiKjHB7X55cz0RMFvWVGR3eRwV1wb3+yq0OXDEqhUhxqoNv6iYWKjkMcLhEF
# xvJAeNcLAyT+XdM5i2CgGPGcb95WJLiw7HzLiBKrxmDj1EQB/mG5eEiRBEp7dDGz
# xKCnTYocDOcRr9KxqHydajmEkzXHOeRGwU+7qt8Md5l4bVZrXAhK+WSk5CihNQsW
# bzT1nRliVDwunuLkX1hyIWXIArCfrKM3+RHh+Sq5RZ8aYyik2r8HxT+l2hmRllBv
# E2Wok6IEaAJanHr24qoqFM9WLeBUSudz+qL51HwDYyIDPSQ3SeHtKog0ZubDk4hE
# LQSxnfVYXdTGncaBnB60QrEuazvcob9n4yR65pUNBCF5qeA4QwYnilBkfnmeAjRN
# 3LVuLr0g0FXkqfYdUmj1fFFhH8k8YBozrEaXnsSL3kdTD01X+4LfIWOuFzTzuosl
# BrBILfHNj8RfOxPgjuwNvE6YzauXi4orp4Sm6tF245DaFOSYbWFK5ZgG6cUY2/bU
# q3g3bQAqZt65KcaewEJ3ZyNEobv35Nf6xN6FrA6jF9447+NHvCjeWLCQZ3M8lgeC
# cnnhTFtyQX3XgCoc6IRXvFOcPVrr3D9RPHCMS6Ckg8wggTrtIVnY8yjbvGOUsAdZ
# beXUIQAWMs0d3cRDv09SvwVRd61evQIDAQABo4ICGzCCAhcwDgYDVR0PAQH/BAQD
# AgGGMBAGCSsGAQQBgjcVAQQDAgEAMB0GA1UdDgQWBBRraSg6NS9IY0DPe9ivSek+
# 2T3bITBUBgNVHSAETTBLMEkGBFUdIAAwQTA/BggrBgEFBQcCARYzaHR0cDovL3d3
# dy5taWNyb3NvZnQuY29tL3BraW9wcy9Eb2NzL1JlcG9zaXRvcnkuaHRtMBMGA1Ud
# JQQMMAoGCCsGAQUFBwMIMBkGCSsGAQQBgjcUAgQMHgoAUwB1AGIAQwBBMA8GA1Ud
# EwEB/wQFMAMBAf8wHwYDVR0jBBgwFoAUyH7SaoUqG8oZmAQHJ89QEE9oqKIwgYQG
# A1UdHwR9MHsweaB3oHWGc2h0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2lvcHMv
# Y3JsL01pY3Jvc29mdCUyMElkZW50aXR5JTIwVmVyaWZpY2F0aW9uJTIwUm9vdCUy
# MENlcnRpZmljYXRlJTIwQXV0aG9yaXR5JTIwMjAyMC5jcmwwgZQGCCsGAQUFBwEB
# BIGHMIGEMIGBBggrBgEFBQcwAoZ1aHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3Br
# aW9wcy9jZXJ0cy9NaWNyb3NvZnQlMjBJZGVudGl0eSUyMFZlcmlmaWNhdGlvbiUy
# MFJvb3QlMjBDZXJ0aWZpY2F0ZSUyMEF1dGhvcml0eSUyMDIwMjAuY3J0MA0GCSqG
# SIb3DQEBDAUAA4ICAQBfiHbHfm21WhV150x4aPpO4dhEmSUVpbixNDmv6TvuIHv1
# xIs174bNGO/ilWMm+Jx5boAXrJxagRhHQtiFprSjMktTliL4sKZyt2i+SXncM23g
# RezzsoOiBhv14YSd1Klnlkzvgs29XNjT+c8hIfPRe9rvVCMPiH7zPZcw5nNjthDQ
# +zD563I1nUJ6y59TbXWsuyUsqw7wXZoGzZwijWT5oc6GvD3HDokJY401uhnj3ubB
# hbkR83RbfMvmzdp3he2bvIUztSOuFzRqrLfEvsPkVHYnvH1wtYyrt5vShiKheGpX
# a2AWpsod4OJyT4/y0dggWi8g/tgbhmQlZqDUf3UqUQsZaLdIu/XSjgoZqDjamzCP
# JtOLi2hBwL+KsCh0Nbwc21f5xvPSwym0Ukr4o5sCcMUcSy6TEP7uMV8RX0eH/4JL
# EpGyae6Ki8JYg5v4fsNGif1OXHJ2IWG+7zyjTDfkmQ1snFOTgyEX8qBpefQbF0fx
# 6URrYiarjmBprwP6ZObwtZXJ23jK3Fg/9uqM3j0P01nzVygTppBabzxPAh/hHhhl
# s6kwo3QLJ6No803jUsZcd4JQxiYHHc+Q/wAMcPUnYKv/q2O444LO1+n6j01z5mgg
# CSlRwD9faBIySAcA9S8h22hIAcRQqIGEjolCK9F6nK9ZyX4lhthsGHumaABdWzCC
# B5YwggV+oAMCAQICEzMAAAAeE1faQDfN/IIAAAAAAB4wDQYJKoZIhvcNAQEMBQAw
# YTELMAkGA1UEBhMCVVMxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEy
# MDAGA1UEAxMpTWljcm9zb2Z0IFB1YmxpYyBSU0EgVGltZXN0YW1waW5nIENBIDIw
# MjAwHhcNMjIwNzA3MTgzNzIyWhcNMjMwNzA3MTgzNzIyWjCB2jELMAkGA1UEBhMC
# VVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNV
# BAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjElMCMGA1UECxMcTWljcm9zb2Z0IEFt
# ZXJpY2EgT3BlcmF0aW9uczEmMCQGA1UECxMdVGhhbGVzIFRTUyBFU046M0RBNS05
# NjNCLUUxRjQxNTAzBgNVBAMTLE1pY3Jvc29mdCBQdWJsaWMgUlNBIFRpbWUgU3Rh
# bXBpbmcgQXV0aG9yaXR5MIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEA
# 3fZPpEOFAKTiwUty7AuI+lnjfCS6nsLwdPqJq8pya3/FcVJdL05CqhY0F4LXK7V+
# egFek3Y/j8wkE+HIewIcT1eZw2F01kMPLVg6bIYzL1Ki/tHlEmrjHK4wyyH/ALVB
# 8NlnTPPPuCU2PVPeCAY0M/NlaYwLTIpzOsuaIfpdkZUe0N1wR4Ou0Tf+GWNO+Yqj
# LffXvhDvB0+aRcSlfbcyO9N/4ak7iZiRuSROTF0Xq1CvAzd18gLt11QqDEpDvtss
# mzHjX7dRbLL58T3FvIFe/+cpjH8sBLAPQRZIu4CayxPj23aUk+0/ZjFFP9mm63Dj
# PWuD+P6eznEnUW99osJWyrRXgSD1L275jjFrdChl23OEVSNRsIhOVkrU6A5eT0yF
# DmJZohT/IA1m2eGj9IYCN/bfKGPeR0tFE+mDKtPbpbidW1c05757Z3xbjwRw+kST
# YRH4fCw+6kj7WDQuS3vMoe52E4yyRRN/nEA7YTfEd240NBXplvgVhYd/RJU32QM+
# /GfTqNnDXhqOpBVvRDLGmqqIOJDHYTEWpZ+pgadtHDyg/sZAi774mP1Wmd0JI/vi
# AGnHD89Z0v28NhuZ2ziYnlzKhRtkB9HQVH9iblfdE1FlmDdOU2Xwzzxzjc5ZT6C2
# sqrI1qdFg8aiPZBgNzgAAyUGxDAZQN3E7+HmOpjk9WECAwEAAaOCAcswggHHMB0G
# A1UdDgQWBBRlUo5CpFmSz7AL1SsS51IUgA0PyjAfBgNVHSMEGDAWgBRraSg6NS9I
# Y0DPe9ivSek+2T3bITBsBgNVHR8EZTBjMGGgX6BdhltodHRwOi8vd3d3Lm1pY3Jv
# c29mdC5jb20vcGtpb3BzL2NybC9NaWNyb3NvZnQlMjBQdWJsaWMlMjBSU0ElMjBU
# aW1lc3RhbXBpbmclMjBDQSUyMDIwMjAuY3JsMHkGCCsGAQUFBwEBBG0wazBpBggr
# BgEFBQcwAoZdaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraW9wcy9jZXJ0cy9N
# aWNyb3NvZnQlMjBQdWJsaWMlMjBSU0ElMjBUaW1lc3RhbXBpbmclMjBDQSUyMDIw
# MjAuY3J0MAwGA1UdEwEB/wQCMAAwFgYDVR0lAQH/BAwwCgYIKwYBBQUHAwgwDgYD
# VR0PAQH/BAQDAgeAMGYGA1UdIARfMF0wUQYMKwYBBAGCN0yDfQEBMEEwPwYIKwYB
# BQUHAgEWM2h0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2lvcHMvRG9jcy9SZXBv
# c2l0b3J5Lmh0bTAIBgZngQwBBAIwDQYJKoZIhvcNAQEMBQADggIBABpLmosDzHWX
# jN6Y+Ygcypex07DR80vVhHtJQIdBlSeve7bc2czMsfdAvCzZAehbmNAE7q/WdL70
# nPz/XoUD8FWySVqkoeiEooU17s3RYntFBM/9TNea704lUbyvzQbpxczZ2j9YomHw
# of4jaDwTR/cOZfNs8qOvOBiZvzGHpKc8RIx7tFrvTs8xRT0aiSnb3GheutPe/RD4
# A2Vc0JrN40m+IdFqlj+lXoeYxfzQo7pkQv3IYdTKY1yAaGvmzqYlUCMUmDTvUG27
# Y+4ugJIoKqHkuN6xHs35US/ddvqo6537e8ud55UDS8XsDrxl5iDEqUYdgXInuJVw
# eJ2f0BWDTxbqnyMv6YTMGFyZirNQbsLyUEw3i2Jq73ORTzlysqk+dcpeHa4bbait
# sJUOxzF1sXXsAdo04tmtFgF4X4BvtBOoXcB4uTFnUrAVh5dA2SSukjNct4WgC4Lq
# qnhSklOlwyZXjVsGSacOfGJtF5IF4DlQ6QfCd4W376ntnexSBlQXlpqM5vikUmr/
# IHPGHZ5h9J8HUStqpxv+IDu8Qc5WjCnAxXFqCbvSILgF2ww0M5qmvmfQ+howqW34
# fXdcLULS5TADiQ5PFm97sMbzasQkLK205yX5HRfvyR/7ZzmIKrrHJEbc/Or6/g2E
# SjbujxRLWgd76JPy3c/bpJL9fhcWYbBvoYICwjCCAisCAQEwggEIoYHgpIHdMIHa
# MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVk
# bW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSUwIwYDVQQLExxN
# aWNyb3NvZnQgQW1lcmljYSBPcGVyYXRpb25zMSYwJAYDVQQLEx1UaGFsZXMgVFNT
# IEVTTjozREE1LTk2M0ItRTFGNDE1MDMGA1UEAxMsTWljcm9zb2Z0IFB1YmxpYyBS
# U0EgVGltZSBTdGFtcGluZyBBdXRob3JpdHmiIwoBATAHBgUrDgMCGgMVAM1Bxj1I
# HdN9eART5MEzS1/UHwtuoGcwZaRjMGExCzAJBgNVBAYTAlVTMR4wHAYDVQQKExVN
# aWNyb3NvZnQgQ29ycG9yYXRpb24xMjAwBgNVBAMTKU1pY3Jvc29mdCBQdWJsaWMg
# UlNBIFRpbWVzdGFtcGluZyBDQSAyMDIwMA0GCSqGSIb3DQEBBQUAAgUA6BphJzAi
# GA8yMDIzMDUyNjA2MzUxOVoYDzIwMjMwNTI3MDYzNTE5WjB3MD0GCisGAQQBhFkK
# BAExLzAtMAoCBQDoGmEnAgEAMAoCAQACAgs3AgH/MAcCAQACAhC2MAoCBQDoG7Kn
# AgEAMDYGCisGAQQBhFkKBAIxKDAmMAwGCisGAQQBhFkKAwKgCjAIAgEAAgMHoSCh
# CjAIAgEAAgMBhqAwDQYJKoZIhvcNAQEFBQADgYEAZ3chfknotvHy6mmepLC4o3sX
# TBL4gPR3RHWof4qnMx+ICOmCHbM/6SyBZWeyQnk/b7yhAEZqVeuTil1ZhNslUfP6
# VKXZa8EUsTrXVB9saxUyjsBVMhu2COUHm6QVqmGmzX7Zx22W8rSUx2N2Km+UkAm1
# YXoRHVSywP3IOJmkmYUxggPUMIID0AIBATB4MGExCzAJBgNVBAYTAlVTMR4wHAYD
# VQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xMjAwBgNVBAMTKU1pY3Jvc29mdCBQ
# dWJsaWMgUlNBIFRpbWVzdGFtcGluZyBDQSAyMDIwAhMzAAAAHhNX2kA3zfyCAAAA
# AAAeMA0GCWCGSAFlAwQCAQUAoIIBLTAaBgkqhkiG9w0BCQMxDQYLKoZIhvcNAQkQ
# AQQwLwYJKoZIhvcNAQkEMSIEILu9fJnh77MlvMEjO5H6pODoyE03yxLYW+EqJePa
# FizxMIHdBgsqhkiG9w0BCRACLzGBzTCByjCBxzCBoAQgXMsRpXs9MbviT54FllX/
# 5bLUwjnQZfEEPs5gf0ikodcwfDBlpGMwYTELMAkGA1UEBhMCVVMxHjAcBgNVBAoT
# FU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEyMDAGA1UEAxMpTWljcm9zb2Z0IFB1Ymxp
# YyBSU0EgVGltZXN0YW1waW5nIENBIDIwMjACEzMAAAAeE1faQDfN/IIAAAAAAB4w
# IgQgSsF6HRfFHBXm1whP5/1WDAMJg11SMyWEKSGDtWO1v7YwDQYJKoZIhvcNAQEL
# BQAEggIAj8MbOvX3sOZ7EVQUMytmnHIQ+cmjuwvw+XdkCxLPLTfeSBmSFpwiYeQx
# 7EViPUldRCx4T6J0yKXxTudaBsrxuRTuTUPGlmn0/cpIupHZ9zlF/wL+WT5k9ARd
# XtbQglAsyOpjSAWZBSieyEFvqfNDq9tIjfyjuf6x7gBBlQ295R6iIVb/xnXlNFRS
# kO1VbVfoZgKBGC4E7PWV5TPLfdSYHzKPc+Qb6rC4kP5JcVvpWHerCAaLlm2b6fwd
# WhW89c+7W4tgaavyKf4q0B2h63oLW7ZdtV7A7oncJGYF9cwncCn5BKyxiiGD0rq7
# Wo+YzoH/2rjmsoNlImAVeie7wOmeMf2kA/KtiEXMH0rcIueaDPKi0pT8xopIteHf
# q2ftWntWkv781zLSorgy3ys0LkPnrjiziJv4aepx4KwQuABsA7bxSlteDXWFUK1D
# gjgkUULR3sbhig8FEbjv9mr/lPr3AcQzbyMH6i6Teo2u0roa9Kjq2mfrDtbqthYQ
# vqz0HkOQ8VL0njUC5stq0yn6LHk6nuBKwJX9/Y4dvsJ5pg4lMQXHErtVo9sk9Tvt
# vAxaRELrNtLNxg/ZJpYnc5696CDVyxGCISF7SSvTHyOAcX7a77uNA8PRzsauChNW
# QwxFOlphOhOl0AV4/+yenhswb2g8jhlKfx/rolD/WtK9dmsu5uk=
# SIG # End signature block
